====
Toot
====

Post to Mastodon social networks from the command line.


Installation
------------

Install using pip:

.. code-block::

    pip install toot


Usage
-----

Currently implements only posting a new status:


.. code-block::

    toot post "Hello world!"

On first use, will ask you to choose a Mastodon instance and log in.
